@@ -118,28 +118,28 @@ class TestWatcher < Test::Unit::TestCase
 
   def test_x_current_header
     env = @req.class.env_for "/active/#@addr.txt"
-    status, headers, body = @app.call(env)
+    _status, headers, _body = @app.call(env)
     assert_equal "0", headers["X-Current"], headers.inspect
 
     env = @req.class.env_for "/queued/#@addr.txt"
-    status, headers, body = @app.call(env)
+    _status, headers, _body = @app.call(env)
     assert_equal "1", headers["X-Current"], headers.inspect
 
     @ios << @srv.accept
     sleep 0.1
 
     env = @req.class.env_for "/queued/#@addr.txt"
-    status, headers, body = @app.call(env)
+    _status, headers, _body = @app.call(env)
     assert_equal "0", headers["X-Current"], headers.inspect
 
     env = @req.class.env_for "/active/#@addr.txt"
-    status, headers, body = @app.call(env)
+    _status, headers, _body = @app.call(env)
     assert_equal "1", headers["X-Current"], headers.inspect
   end
 
   def test_peaks
     env = @req.class.env_for "/active/#@addr.txt"
-    status, headers, body = @app.call(env.dup)
+    _status, headers, _body = @app.call(env.dup)
     start = headers["X-First-Peak-At"]
     assert headers["X-First-Peak-At"], headers.inspect
     assert headers["X-Last-Peak-At"], headers.inspect
@@ -148,14 +148,14 @@ class TestWatcher < Test::Unit::TestCase
     before = headers["X-Last-Peak-At"]
 
     env = @req.class.env_for "/queued/#@addr.txt"
-    status, headers, body = @app.call(env)
+    _status, headers, _body = @app.call(env)
     assert_nothing_raised { Time.parse(headers["X-First-Peak-At"]) }
     assert_nothing_raised { Time.parse(headers["X-Last-Peak-At"]) }
     assert_equal before, headers["X-Last-Peak-At"], "should not change"
 
     sleep 2
     env = @req.class.env_for "/active/#@addr.txt"
-    status, headers, body = @app.call(env.dup)
+    _status, headers, _body = @app.call(env.dup)
     assert_equal before, headers["X-Last-Peak-At"], headers.inspect
 
     @ios << @srv.accept
@@ -167,7 +167,7 @@ class TestWatcher < Test::Unit::TestCase
     end
     sleep 0.1
     env = @req.class.env_for "/queued/#@addr.txt"
-    status, headers, body = @app.call(env.dup)
+    _status, headers, _body = @app.call(env.dup)
     assert headers["X-Last-Peak-At"], headers.inspect
     assert_nothing_raised { Time.parse(headers["X-Last-Peak-At"]) }
     assert before != headers["X-Last-Peak-At"]
@@ -177,7 +177,7 @@ class TestWatcher < Test::Unit::TestCase
     sleep 2
 
     env = @req.class.env_for "/queued/#@addr.txt"
-    status, headers, body = @app.call(env)
+    _status, headers, _body = @app.call(env)
     assert_equal "0", headers["X-Current"]
     assert_nothing_raised { Time.parse(headers["X-Last-Peak-At"]) }
     assert_equal queued_before, headers["X-Last-Peak-At"], "should not change"
